@@ -4,8 +4,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/afs/DARWIN/osi_vfsops.c,v 1.11.2.5 2007/01/04 22:09:50 shadow Exp $");
 
 #include <afs/sysincludes.h>	/* Standard vendor system headers */
 #include <afsincludes.h>	/* Afs-based standard headers */
@@ -118,7 +116,7 @@ afs_mount(mp, path, data, ndp, ctx)
     afs_globalVFS = mp;
 #ifdef AFS_DARWIN80_ENV
     vfs_ioattr(mp, &ioattr);
-    ioattr.io_devblocksize = 8192;
+    ioattr.io_devblocksize = (16 * 32768);
     vfs_setioattr(mp, &ioattr);
     /* f_iosize is handled in VFS_GETATTR */
 #else
@@ -366,28 +364,23 @@ afs_statfs(struct mount *mp, STATFS_TYPE *abp, CTX_TYPE ctx)
     AFS_GLOCK();
     AFS_STATCNT(afs_statfs);
 
-#if 0
-    abp->f_type = MOUNT_AFS;
-#endif
 #ifdef AFS_DARWIN80_ENV
-    abp->f_bsize = abp->f_iosize = vfs_devblocksize(mp);
+    abp->f_iosize = (256 * 1024);
+    abp->f_bsize = vfs_devblocksize(mp);
 #else
     abp->f_bsize = mp->vfs_bsize;
     abp->f_iosize = mp->vfs_bsize;
 #endif
+#if 0
+    abp->f_type = MOUNT_AFS;
+#endif
 
     /* Fake a high number below to satisfy programs that use the statfs call
      * to make sure that there's enough space in the device partition before
      * storing something there.
      */
     abp->f_blocks = abp->f_bfree = abp->f_bavail = abp->f_files =
-	abp->f_ffree = 
-#ifdef AFS_DARWIN80_ENV
-	2147483648
-#else
-	2000000
-#endif
-	;
+	abp->f_ffree = 0x7fffffff;
 
     if (abp != sysstat) {
         abp->f_fsid.val[0] = sysstat->f_fsid.val[0];
