@@ -103,6 +103,9 @@ static inline time_t osi_Time(void) {
 #undef gop_lookupname
 #define gop_lookupname osi_lookupname
 
+#undef gop_lookupname_user
+#define gop_lookupname_user osi_lookupname
+
 #define osi_vnhold(V, N) do { VN_HOLD(AFSTOV(V)); } while (0)
 #define VN_HOLD(V) osi_Assert(igrab((V)) == (V))
 #define VN_RELE(V) iput((V))
