@@ -15,8 +15,6 @@
 #include <afsconfig.h>
 #include "afs/param.h"
 
-RCSID
-    ("$Header: /cvs/openafs/src/afs/LINUX/osi_vfsops.c,v 1.29.2.31 2009/03/18 12:57:17 shadow Exp $");
 
 #define __NO_VERSION__		/* don't define kernel_version in module.h */
 #include <linux/module.h> /* early to avoid printf->printk mapping */
@@ -30,6 +28,7 @@ RCSID
 #include "h/smp_lock.h"
 #endif
 
+#include "osi_compat.h"
 
 struct vcache *afs_globalVp = 0;
 struct vfs *afs_globalVFS = 0;
@@ -102,9 +101,7 @@ struct file_system_type afs_fs_type = {
 #endif
 
 #if defined(AFS_LINUX26_ENV)
-struct backing_dev_info afs_backing_dev_info = {
-    .ra_pages		= 0, /* disable readahead, afs does prefetch */
-};
+struct backing_dev_info *afs_backing_dev_info;
 
 int
 afs_fill_super(struct super_block *sb, void *data, int silent)
@@ -143,8 +140,19 @@ afs_read_super(struct super_block *sb, void *data, int silent)
     sb->s_blocksize_bits = 10;
     sb->s_magic = AFS_VFSMAGIC;
     sb->s_op = &afs_sops;	/* Super block (vfs) ops */
+    /* used for inodes backing_dev_info field, also */
+    afs_backing_dev_info = osi_Alloc(sizeof(struct backing_dev_info));
 #if defined(HAVE_BDI_INIT)
-    bdi_init(&afs_backing_dev_info);
+    bdi_init(afs_backing_dev_info);
+#endif
+#if defined(STRUCT_BDI_HAS_NAME)
+    afs_backing_dev_info->name = "openafs";
+#endif
+    afs_backing_dev_info->ra_pages = 0;
+#if defined (STRUCT_SUPER_BLOCK_HAS_S_BDI)
+    sb->s_bdi = afs_backing_dev_info;
+    /* The name specified here will appear in the flushing thread name - flush-afs */
+    bdi_register(afs_backing_dev_info, NULL, "afs");
 #endif
 #if defined(MAX_NON_LFS)
 #ifdef AFS_64BIT_CLIENT
@@ -163,6 +171,7 @@ afs_read_super(struct super_block *sb, void *data, int silent)
     code = afs_root(sb);
     if (code) {
 	afs_globalVFS = NULL;
+	osi_linux_free_inode_pages();
 #if defined(AFS_LINUX26_ENV)
         module_put(THIS_MODULE);
 #else
@@ -266,22 +275,14 @@ afs_notify_change(struct dentry *dp, struct iattr *iattrp)
 
 
 #if defined(STRUCT_SUPER_HAS_ALLOC_INODE)
-#if defined(HAVE_KMEM_CACHE_T)
-static kmem_cache_t *afs_inode_cachep;
-#else
-struct kmem_cache *afs_inode_cachep;
-#endif
+static afs_kmem_cache_t *afs_inode_cachep;
 
 static struct inode *
 afs_alloc_inode(struct super_block *sb)
 {
     struct vcache *vcp;
 
-#if defined(SLAB_KERNEL)
-    vcp = (struct vcache *) kmem_cache_alloc(afs_inode_cachep, SLAB_KERNEL);
-#else
-    vcp = (struct vcache *) kmem_cache_alloc(afs_inode_cachep, GFP_KERNEL);
-#endif
+    vcp = (struct vcache *) kmem_cache_alloc(afs_inode_cachep, KALLOC_TYPE);
     if (!vcp)
 	return NULL;
 
@@ -294,43 +295,25 @@ afs_destroy_inode(struct inode *inode)
     kmem_cache_free(afs_inode_cachep, inode);
 }
 
-static void
-#if defined(HAVE_KMEM_CACHE_T)
-init_once(void * foo, kmem_cache_t * cachep, unsigned long flags)
-#else
-#if defined(KMEM_CACHE_INIT)
-init_once(struct kmem_cache * cachep, void * foo)
-#else
-init_once(void * foo, struct kmem_cache * cachep, unsigned long flags)
-#endif
-#endif
+void
+init_once(void * foo)
 {
     struct vcache *vcp = (struct vcache *) foo;
 
-#if defined(SLAB_CTOR_VERIFY)
-    if ((flags & (SLAB_CTOR_VERIFY|SLAB_CTOR_CONSTRUCTOR)) ==
-	SLAB_CTOR_CONSTRUCTOR)
-#endif
-	inode_init_once(AFSTOV(vcp));
+    inode_init_once(AFSTOV(vcp));
 }
 
 int
 afs_init_inodecache(void)
 {
-#ifndef SLAB_RECLAIM_ACCOUNT
-#define SLAB_RECLAIM_ACCOUNT 0
-#endif
-
 #if defined(KMEM_CACHE_TAKES_DTOR)
     afs_inode_cachep = kmem_cache_create("afs_inode_cache",
-					 sizeof(struct vcache),
-					 0, SLAB_HWCACHE_ALIGN | SLAB_RECLAIM_ACCOUNT,
-					 init_once, NULL);
+		sizeof(struct vcache), 0,
+		SLAB_HWCACHE_ALIGN | SLAB_RECLAIM_ACCOUNT, init_once_func, NULL);
 #else
     afs_inode_cachep = kmem_cache_create("afs_inode_cache",
-					 sizeof(struct vcache),
-					 0, SLAB_HWCACHE_ALIGN | SLAB_RECLAIM_ACCOUNT,
-					 init_once);
+		sizeof(struct vcache), 0,
+		SLAB_HWCACHE_ALIGN | SLAB_RECLAIM_ACCOUNT, init_once_func);
 #endif
     if (afs_inode_cachep == NULL)
 	return -ENOMEM;
@@ -398,8 +381,9 @@ afs_put_super(struct super_block *sbp)
 
     osi_linux_verify_alloced_memory();
 #if defined(HAVE_BDI_INIT)
-    bdi_destroy(&afs_backing_dev_info);
+    bdi_destroy(afs_backing_dev_info);
 #endif
+    osi_Free(afs_backing_dev_info, sizeof(struct backing_dev_info));
     AFS_GUNLOCK();
 
     sbp->s_dev = 0;
