@@ -8,16 +8,14 @@
  */
 
 #include <afsconfig.h>
-#include "../afs/param.h"
+#include "afs/param.h"
 
-RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/afs/SOLARIS/osi_vm.c,v 1.1.1.5 2002/05/10 23:44:14 hartmans Exp $");
 
-#include "../afs/sysincludes.h"	/* Standard vendor system headers */
-#include "../afs/afsincludes.h"	/* Afs-based standard headers */
-#include "../afs/afs_stats.h"  /* statistics */
-#include "../afs/nfsclient.h"  
+#include "afs/sysincludes.h"	/* Standard vendor system headers */
+#include "afsincludes.h"	/* Afs-based standard headers */
+#include "afs/afs_stats.h"	/* statistics */
+#include "afs/nfsclient.h"
 
-#if	defined(AFS_SUN5_ENV)
 /* This file contains Solaris VM-related code for the cache manager. */
 
 #include <sys/mman.h>
@@ -43,17 +41,14 @@ RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/afs/SOL
  * Locking:  only the global lock is held on entry.
  */
 int
-osi_VM_GetDownD(avc, adc)
-    struct vcache *avc;
-    struct dcache *adc;
+osi_VM_GetDownD(struct vcache *avc, struct dcache *adc)
 {
     int code;
 
     AFS_GUNLOCK();
-    code = afs_putpage(AFSTOV(avc),
-		       (offset_t) AFS_CHUNKTOBASE(adc->f.chunk),
-		       AFS_CHUNKTOSIZE(adc->f.chunk),
-		       B_INVAL, CRED());
+    code =
+	afs_putpage(AFSTOV(avc), (offset_t) AFS_CHUNKTOBASE(adc->f.chunk),
+		    AFS_CHUNKTOSIZE(adc->f.chunk), B_INVAL, CRED());
     AFS_GLOCK();
 
     return code;
@@ -74,9 +69,7 @@ osi_VM_GetDownD(avc, adc)
  * therefore obsolescent.
  */
 int
-osi_VM_FlushVCache(avc, slept)
-    struct vcache *avc;
-    int *slept;
+osi_VM_FlushVCache(struct vcache *avc, int *slept)
 {
     if (avc->vrefCount != 0)
 	return EBUSY;
@@ -91,12 +84,12 @@ osi_VM_FlushVCache(avc, slept)
 	return EBUSY;
 
     AFS_GUNLOCK();
-    pvn_vplist_dirty(AFSTOV(avc), 0, NULL, B_TRUNC|B_INVAL, CRED());
+    pvn_vplist_dirty(AFSTOV(avc), 0, NULL, B_TRUNC | B_INVAL, CRED());
     AFS_GLOCK();
 
     /* Might as well make the obvious check */
     if (AFSTOV(avc)->v_pages)
-	return EBUSY;	/* should be all gone still */
+	return EBUSY;		/* should be all gone still */
 
     rw_destroy(&avc->rwlock);
     if (avc->credp) {
@@ -114,15 +107,14 @@ osi_VM_FlushVCache(avc, slept)
  * re-obtained.
  */
 void
-osi_VM_StoreAllSegments(avc)
-    struct vcache *avc;
+osi_VM_StoreAllSegments(struct vcache *avc)
 {
     AFS_GUNLOCK();
 #if	defined(AFS_SUN56_ENV)
-    (void) pvn_vplist_dirty(AFSTOV(avc), (u_offset_t)0, afs_putapage,
-			    0, CRED());
+    (void)pvn_vplist_dirty(AFSTOV(avc), (u_offset_t) 0, afs_putapage, 0,
+			   CRED());
 #else
-    (void) pvn_vplist_dirty(AFSTOV(avc), 0, afs_putapage, 0, CRED());
+    (void)pvn_vplist_dirty(AFSTOV(avc), 0, afs_putapage, 0, CRED());
 #endif
     AFS_GLOCK();
 }
@@ -134,18 +126,15 @@ osi_VM_StoreAllSegments(avc)
  * re-obtained.
  */
 void
-osi_VM_TryToSmush(avc, acred, sync)
-    struct vcache *avc;
-    struct AFS_UCRED *acred;
-    int sync;
+osi_VM_TryToSmush(struct vcache *avc, struct AFS_UCRED *acred, int sync)
 {
     AFS_GUNLOCK();
 #if	defined(AFS_SUN56_ENV)
-    (void) pvn_vplist_dirty(AFSTOV(avc), (u_offset_t)0, afs_putapage,
-			    (sync ? B_INVAL : B_FREE), acred);
+    (void)pvn_vplist_dirty(AFSTOV(avc), (u_offset_t) 0, afs_putapage,
+			   (sync ? B_INVAL : B_FREE), acred);
 #else
-    (void) pvn_vplist_dirty(AFSTOV(avc), 0, afs_putapage,
-			    (sync ? B_INVAL : B_FREE), acred);
+    (void)pvn_vplist_dirty(AFSTOV(avc), 0, afs_putapage,
+			   (sync ? B_INVAL : B_FREE), acred);
 #endif
     AFS_GLOCK();
 }
@@ -155,15 +144,12 @@ osi_VM_TryToSmush(avc, acred, sync)
  * Locking:  No lock is held, not even the global lock.
  */
 void
-osi_VM_FlushPages(avc, credp)
-    struct vcache *avc;
-    struct AFS_UCRED *credp;
+osi_VM_FlushPages(struct vcache *avc, struct AFS_UCRED *credp)
 {
     extern int afs_pvn_vptrunc;
 
     afs_pvn_vptrunc++;
-    (void) afs_putpage(AFSTOV(avc), (offset_t)0, 0,
-			B_TRUNC|B_INVAL, credp);
+    (void)afs_putpage(AFSTOV(avc), (offset_t) 0, 0, B_TRUNC | B_INVAL, credp);
 }
 
 /* Zero no-longer-used part of last page, when truncating a file
@@ -175,10 +161,7 @@ osi_VM_FlushPages(avc, credp)
  * be called first, since it causes a pagein.
  */
 void
-osi_VM_PreTruncate(avc, alen, acred)
-    struct vcache *avc;
-    int alen;
-    struct AFS_UCRED *acred;
+osi_VM_PreTruncate(struct vcache *avc, int alen, struct AFS_UCRED *acred)
 {
     page_t *pp;
     int pageOffset = (alen & PAGEOFFSET);
@@ -195,7 +178,7 @@ osi_VM_PreTruncate(avc, alen, acred)
 	page_unlock(pp);
     }
     AFS_GLOCK();
-    ObtainWriteLock(&avc->lock,563);
+    ObtainWriteLock(&avc->lock, 563);
 }
 
 /* Purge pages beyond end-of-file, when truncating a file.
@@ -204,17 +187,12 @@ osi_VM_PreTruncate(avc, alen, acred)
  * Pageins are blocked (activeV is raised).
  */
 void
-osi_VM_Truncate(avc, alen, acred)
-    struct vcache *avc;
-    int alen;
-    struct AFS_UCRED *acred;
+osi_VM_Truncate(struct vcache *avc, int alen, struct AFS_UCRED *acred)
 {
     /*
      * It's OK to specify afs_putapage here, even though we aren't holding
      * the vcache entry lock, because it isn't going to get called.
      */
-    pvn_vplist_dirty(AFSTOV(avc), alen, afs_putapage, B_TRUNC|B_INVAL,
+    pvn_vplist_dirty(AFSTOV(avc), alen, afs_putapage, B_TRUNC | B_INVAL,
 		     acred);
 }
-
-#endif /* SUN5 && !NCR */
