@@ -13,8 +13,6 @@
 #include <afsconfig.h>
 #include "afs/param.h"
 
-RCSID
-    ("$Header: /cvs/openafs/src/afs/afs_analyze.c,v 1.22.2.9 2009/06/24 21:30:14 shadow Exp $");
 
 #include "afs/stds.h"
 #include "afs/sysincludes.h"	/* Standard vendor system headers */
@@ -544,7 +542,7 @@ afs_Analyze(register struct afs_conn *aconn, afs_int32 acode,
     afs_int32 i;
     struct srvAddr *sa;
     struct server *tsp;
-    struct volume *tvp;
+    struct volume *tvp = NULL;
     afs_int32 shouldRetry = 0;
     afs_int32 serversleft = 1;
     struct afs_stats_RPCErrors *aerrP;
@@ -674,12 +672,18 @@ afs_Analyze(register struct afs_conn *aconn, afs_int32 acode,
     if ((acode < 0) && (acode != VRESTARTING)) {
 	if (acode == RX_CALL_TIMEOUT) {
 	    serversleft = afs_BlackListOnce(areq, afid, tsp);
-	    areq->idleError++;
-	    if (serversleft) {
-		shouldRetry = 1;
-	    } else {
+	    if (afid)
+		tvp = afs_FindVolume(afid, READ_LOCK);
+	    if (!afid || !tvp || (tvp->states & VRO))
+		areq->idleError++;
+	    if ((serversleft == 0) && tvp &&
+		((tvp->states & VRO) || (tvp->states & VBackup))) {
 		shouldRetry = 0;
+	    } else {
+		shouldRetry = 1;
 	    }
+	    if (tvp)
+		afs_PutVolume(tvp, READ_LOCK);
 	    /* By doing this, we avoid ever marking a server down
 	     * in an idle timeout case. That's because the server is 
 	     * still responding and may only be letting a single vnode
