@@ -25,6 +25,7 @@
 #define AFS_NAMEI_ENV     1	/* User space interface to file system */
 #define AFS_64BIT_ENV		1
 #define AFS_64BIT_CLIENT	1
+#define AFS_MAXVCOUNT_ENV       1
 
 #if defined(__KERNEL__) && !defined(KDUMP_KERNEL)
 
@@ -111,6 +112,7 @@
 #define AFS_MOUNT_AFS "afs"	/* The name of the filesystem type. */
 #define AFS_SYSCALL 137
 #define AFS_64BIT_IOPS_ENV  1
+#define AFS_64BIT_ENV		1	/* Defines afs_int32 as int, not long. */
 #define AFS_NAMEI_ENV     1	/* User space interface to file system */
 #include <afs/afs_sysnames.h>
 
