@@ -10,8 +10,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/kauth/kpwvalid.c,v 1.6.2.2 2007/11/26 21:21:52 shadow Exp $");
 
 #include <stdio.h>
 #include <string.h>
@@ -27,7 +25,7 @@ main(int argc, char *argv[])
 {
     char oldpassword[512];
     char password[512];
-    int rc;
+    int rc = 1;
 
     if (fgets(oldpassword, 512, stdin))
 	while (fgets(password, 512, stdin)) {
