@@ -10,8 +10,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/kauth/test/test_rxkad_free.c,v 1.7.2.2 2007/04/10 18:43:43 shadow Exp $");
 
 #include <afs/stds.h>
 #include <sys/types.h>
@@ -52,12 +50,10 @@ PrintRxkadStats()
 	   rxkad_stats.destroyUnauth);
 }
 
-static long
-Main(as, arock)
-     IN struct cmd_syndesc *as;
-     IN char *arock;
+static int
+Main(struct cmd_syndesc *as, void *arock)
 {
-    long code;
+    int code;
     char name[MAXKTCNAMELEN];
     char instance[MAXKTCNAMELEN];
     char newCell[MAXKTCREALMLEN];
@@ -373,7 +369,7 @@ main(argc, argv)
     initialize_ACFG_error_table();
     initialize_KA_error_table();
 
-    ts = cmd_CreateSyntax(0, Main, 0, "Main program");
+    ts = cmd_CreateSyntax(NULL, Main, NULL, "Main program");
     /* 0 */ cmd_AddParm(ts, "-number", CMD_SINGLE, CMD_OPTIONAL,
 			"number of iterations");
     /* 1 */ cmd_AddParm(ts, "-long", CMD_FLAG, CMD_OPTIONAL,
