@@ -16,22 +16,12 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/libadmin/samples/rxdebug_rx_stats.c,v 1.7 2003/10/24 06:26:10 shadow Exp $");
 
 #ifdef AFS_NT40_ENV
 #include <winsock2.h>
 #include <pthread.h>
 #endif
-
-#ifdef HAVE_STRING_H
 #include <string.h>
-#else
-#ifdef HAVE_STRINGS_H
-#include <strings.h>
-#endif
-#endif
-
 #include <afs/afs_Admin.h>
 #include <afs/afs_clientAdmin.h>
 #include <afs/afs_utilAdmin.h>
@@ -76,7 +66,7 @@ main(int argc, char *argv[])
     rxdebugHandle_p handle;
     char *srvrName;
     long srvrPort;
-    struct rx_stats stats;
+    struct rx_statistics stats;
     afs_uint32 supportedStats;
     char tstr[32];
     int i;
