@@ -14,7 +14,7 @@
 #define _CLOCK_
 
 #ifdef	KERNEL
-#if defined(AFS_AIX_ENV) || defined(AFS_AUX_ENV)
+#if defined(AFS_AIX_ENV) || defined(AFS_AUX_ENV) || defined(AFS_SUN5_ENV)
 #include "h/systm.h"
 #include "h/time.h"
 #endif /* System V */
@@ -90,7 +90,7 @@ extern int clock_nUpdates;
 #if defined(AFS_SGI61_ENV) || defined(AFS_HPUX_ENV) || defined(AFS_LINUX_64BIT_KERNEL)
 #define clock_GetTime(cv) osi_GetTime((osi_timeval_t *)cv)
 #else
-#if defined(AFS_AIX51_ENV) && defined(AFS_64BIT_KERNEL)
+#if (defined(AFS_AIX51_ENV) && defined(AFS_64BIT_KERNEL)) || (defined(AFS_DARWIN100_ENV) && defined(__amd64__))
 #define        clock_GetTime(cv)                               \
     BEGIN                                              \
        struct timeval tv;                              \
@@ -99,7 +99,7 @@ extern int clock_nUpdates;
        (cv)->usec = (afs_int32)tv.tv_usec;             \
     END
 #else /* defined(AFS_AIX51_ENV) && defined(AFS_64BIT_KERNEL) */
-#define clock_GetTime(cv) osi_GetTime((struct timeval *)cv)
+#define clock_GetTime(cv) osi_GetTime((osi_timeval_t *)(cv))
 #endif /* defined(AFS_AIX51_ENV) && defined(AFS_64BIT_KERNEL) */
 #endif
 #define clock_Sec() osi_Time()
@@ -110,13 +110,6 @@ extern int clock_nUpdates;
 #define clock_ElapsedTime(cv1, cv2) \
     (((cv2)->sec - (cv1)->sec)*1000 + ((cv2)->usec - (cv1)->usec)/1000)
 
-#ifdef AFS_PTHREAD_ENV
-#define clock_Advance(cv)
-#else
-/* Advance the known value of the current clock time (clock_now) by the specified clock value */
-#define clock_Advance(cv) clock_Add(&clock_now, cv)
-#endif /* AFS_PTHREAD_ENV */
-
 /* Some comparison operators for clock values */
 #define	clock_Gt(a, b)	((a)->sec>(b)->sec || ((a)->sec==(b)->sec && (a)->usec>(b)->usec))
 #define	clock_Ge(a, b)	((a)->sec>(b)->sec || ((a)->sec==(b)->sec && (a)->usec>=(b)->usec))
@@ -140,7 +133,10 @@ extern int clock_nUpdates;
 	(c1)->sec += (c2)->sec;					\
     END
 
+#define USEC(cp)        ((cp->sec * 1000000) + cp->usec)
 #define MSEC(cp)	((cp->sec * 1000) + (cp->usec / 1000))
+#define _4THMSEC(cp)    ((cp->sec * 4000) + (cp->usec / 250))
+#define _8THMSEC(cp)    ((cp->sec * 8000) + (cp->usec / 125))
 
 /* Add ms milliseconds to time c1.  Both ms and c1 must be positive */
 #define	clock_Addmsec(c1, ms)					 \
