@@ -12,8 +12,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/rx/rx_user.c,v 1.18.2.5 2007/10/30 15:24:04 shadow Exp $");
 
 # include <sys/types.h>
 # include <errno.h>
@@ -153,15 +151,26 @@ rxi_GetHostUDPSocket(u_int ahost, u_short port)
 
 	len1 = 32766;
 	len2 = rx_UdpBufSize;
-	greedy =
-	    (setsockopt
-	     (socketFd, SOL_SOCKET, SO_RCVBUF, (char *)&len2,
-	      sizeof(len2)) >= 0);
-	if (!greedy) {
-	    len2 = 32766;	/* fall back to old size... uh-oh! */
-	}
 
-	greedy =
+        /* find the size closest to rx_UdpBufSize that will be accepted */
+        while (!greedy && len2 > len1) {
+            greedy =
+                (setsockopt
+                  (socketFd, SOL_SOCKET, SO_RCVBUF, (char *)&len2,
+                   sizeof(len2)) >= 0);
+            if (!greedy)
+                len2 /= 2;
+        }
+
+        /* but do not let it get smaller than 32K */ 
+        if (len2 < len1)
+            len2 = len1;
+
+        if (len1 < len2)
+            len1 = len2;
+
+
+        greedy =
 	    (setsockopt
 	     (socketFd, SOL_SOCKET, SO_SNDBUF, (char *)&len1,
 	      sizeof(len1)) >= 0)
@@ -665,10 +674,10 @@ rxi_InitPeerParams(struct rx_peer *pp)
     pp->natMTU = MIN((int)pp->ifMTU, OLD_MAX_PACKET_SIZE);
     pp->maxDgramPackets =
 	MIN(rxi_nDgramPackets,
-	    rxi_AdjustDgramPackets(RX_MAX_FRAGS, pp->ifMTU));
+	    rxi_AdjustDgramPackets(rxi_nSendFrags, pp->ifMTU));
     pp->ifDgramPackets =
 	MIN(rxi_nDgramPackets,
-	    rxi_AdjustDgramPackets(RX_MAX_FRAGS, pp->ifMTU));
+	    rxi_AdjustDgramPackets(rxi_nSendFrags, pp->ifMTU));
     pp->maxDgramPackets = 1;
     /* Initialize slow start parameters */
     pp->MTU = MIN(pp->natMTU, pp->maxMTU);
