@@ -10,7 +10,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/sys/iread.c,v 1.1.1.4 2001/07/14 22:24:03 hartmans Exp $");
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -19,8 +18,8 @@ RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/sys/ire
 
 #include "AFS_component_version_number.c"
 
-main(argc,argv)
-char **argv;
+main(argc, argv)
+     char **argv;
 {
 
     struct stat status;
@@ -34,11 +33,14 @@ char **argv;
 	printf("Usage: iread inode offset count\n");
 	exit(1);
     }
-    count = xiread(status.st_dev, atoi(argv[1]), 17, atoi(argv[2]), buf, atoi(argv[3]));
+    count =
+	xiread(status.st_dev, atoi(argv[1]), 17, atoi(argv[2]), buf,
+	       atoi(argv[3]));
     if (count == -1) {
 	perror("iread");
 	exit(1);
     }
-    printf("iread(%x) successful, count==%d.  Data follows:\n%s\n",status.st_dev,  count,buf);
+    printf("iread(%x) successful, count==%d.  Data follows:\n%s\n",
+	   status.st_dev, count, buf);
     exit(0);
 }
