@@ -10,13 +10,13 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb.mit.edu/project/openafs/debian/cvs/openafs/src/util/test/ktest.c,v 1.1.1.4 2001/07/14 22:24:33 hartmans Exp $");
 
 #include "ktime.h"
 
 main(argc, argv)
-int argc;
-char **argv; {
+     int argc;
+     char **argv;
+{
     struct ktime ttime;
     long ntime, code;
 
