@@ -10,8 +10,6 @@
 /* Get CM initialization parameters. */
 #include <afsconfig.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/venus/test/getinitparams.c,v 1.5 2003/07/15 23:17:24 shadow Exp $");
 
 #include <afs/param.h>
 #include <stdio.h>
@@ -34,7 +32,7 @@ RCSID
 
 
 int
-GetInitParamsCmd(struct cmd_syndesc *as)
+GetInitParamsCmd(struct cmd_syndesc *as, void *arock)
 {
     struct cm_initparams cm_initParams;
     struct ViceIoctl blob;
