@@ -10,13 +10,8 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/venus/up.c,v 1.13 2003/07/15 23:17:22 shadow Exp $");
 
 /* missing type from C language */
-#define Boolean short
-#define true 1
-#define false 0
 
 #include <errno.h>
 #ifdef	AFS_AIX32_ENV
@@ -24,6 +19,7 @@ RCSID
 #undef	_NONSTD_TYPES
 #endif
 #include <stdio.h>
+#include <unistd.h>
 #include <afs/afs_args.h>
 #include <sys/param.h>
 #ifdef	AFS_SUN5_ENV
@@ -45,13 +41,7 @@ RCSID
 #include <netinet/in.h>
 #endif
 
-#ifdef HAVE_STRING_H
 #include <string.h>
-#else
-#ifdef HAVE_STRINGS_H
-#include <strings.h>
-#endif
-#endif
 
 #include <afs/venus.h>
 
@@ -64,16 +54,16 @@ extern sys_nerr;
 extern char *sys_errlist[];
 #endif
 
-Boolean verbose = false;
-Boolean renameTargets = false;
-Boolean oneLevel = false;
-Boolean preserveDate = true;
-Boolean preserveMountPoints = false;
-Boolean forceOverwrite = false;
+short verbose = 0;
+short renameTargets = 0;
+short oneLevel = 0;
+short preserveDate = 1;
+short preserveMountPoints = 0;
+short forceOverwrite = 0;
 
 int pageSize;
-Boolean setacl = true;
-Boolean oldAcl = false;
+short setacl = 1;
+short oldAcl = 0;
 char file1[MAXPATHLEN], file2[MAXPATHLEN];
 
 #define	MAXSIZE	2048
@@ -86,6 +76,12 @@ struct OldAcl {
     char data[1];
 };
 
+static void ScanArgs(int argc, char *argv[]);
+static short MakeParent(char *file, afs_int32 owner);
+static int Copy(char *file1, char *file2, short recursive, int level);
+static int isMountPoint(char *name, struct ViceIoctl *blob);
+
+
 /* ************************************************************ */
 /* 								 */
 /* main program							 */
@@ -94,10 +90,8 @@ struct OldAcl {
 
 #include "AFS_component_version_number.c"
 
-main(argc, argv)
-     int argc;
-     char *argv[];
-
+int
+main(int argc, char *argv[])
 {
 #ifdef	AFS_AIX32_ENV
     /*
@@ -120,16 +114,15 @@ main(argc, argv)
 
     /* now read each line of the CopyList */
     if (Copy(file1, file2, !oneLevel, 0))
-	exit(1);		/* some type of failure */
+	return(1);		/* some type of failure */
 
-    exit(0);
+    return(0);
 }
 
 
-ScanArgs(argc, argv)
-     int argc;
-     char *argv[];
-
+#define USAGE "usage: up [-v1frxm] from to\n"
+static void
+ScanArgs(int argc, char *argv[])
 {
     /* skip program name */
     argc--, argv++;
@@ -140,39 +133,39 @@ ScanArgs(argc, argv)
 
 	switch (*++cp) {
 	case 'v':
-	    verbose = true;
+	    verbose = 1;
 	    break;
 
 	case '1':
-	    oneLevel = true;
+	    oneLevel = 1;
 	    break;
 
 	case 'r':
-	    renameTargets = true;
+	    renameTargets = 1;
 	    break;
 
 	case 'f':
-	    forceOverwrite = true;
+	    forceOverwrite = 1;
 	    break;
 
 	case 'x':
-	    preserveDate = false;
+	    preserveDate = 0;
 	    break;
 
 	case 'm':
-	    preserveMountPoints = true;
+	    preserveMountPoints = 1;
 	    break;
 
 	default:
 	    fprintf(stderr, "Unknown option: '%c'\n", *cp);
-	    fprintf(stderr, "usage: up [-v1frxm] from to\n");
+	    fprintf(stderr, USAGE);
 	    exit(1);
 	}
 	argc--, argv++;
     }
 
     if (argc != 2) {
-	fprintf(stderr, "usage: up [-v1frx] from to\n");
+	fprintf(stderr, USAGE);
 	exit(1);
     }
 
@@ -186,13 +179,11 @@ ScanArgs(argc, argv)
 /*
  * MakeParent
  *	Make sure the parent directory of this file exists.  Returns
- * 	true if it exists, false otherwise.  Note: the owner argument
+ * 	1 if it exists, 0 otherwise.  Note: the owner argument
  * 	is a hack.  All directories made will have this owner.
  */
-Boolean
-MakeParent(file, owner)
-     char *file;
-     afs_int32 owner;
+static short
+MakeParent(char *file, afs_int32 owner)
 {
     char parent[MAXPATHLEN];
     char *p;
@@ -211,7 +202,7 @@ MakeParent(file, owner)
 
     if (stat(parent, &s) < 0) {
 	if (!MakeParent(parent, owner))
-	    return (false);
+	    return (0);
 
 	if (verbose) {
 	    printf("Creating directory %s\n", parent);
@@ -221,7 +212,7 @@ MakeParent(file, owner)
 	mkdir(parent, 0777);
 	chown(parent, owner, -1);
     }
-    return (true);
+    return (1);
 }				/*MakeParent */
 
 
@@ -230,12 +221,8 @@ MakeParent(file, owner)
  * 	This does the bulk of the work of the program.  Handle one file,
  *	possibly copying subfiles if this is a directory
  */
-Copy(file1, file2, recursive, level)
-     char *file1;		/* input file name */
-     char *file2;		/* output file name */
-     Boolean recursive;		/* true if directory should be copied */
-     int level;			/* level of recursion: 0, 1, ... */
-
+static int
+Copy(char *file1, char *file2, short recursive, int level)
 {
     struct stat s1, s2;		/*Stat blocks */
     struct ViceIoctl blob;
@@ -528,6 +515,7 @@ Copy(file1, file2, recursive, level)
 	char f1[MAXPATHLEN], f2[MAXPATHLEN];
 	char *p1, *p2;
 	struct dirent *d;
+	struct timeval tv[2];
 
 	if (verbose) {
 	    printf("Level %d: Directory %s to %s\n", level, file1, file2);
@@ -614,7 +602,7 @@ Copy(file1, file2, recursive, level)
 	    rcode = 1;
 	}
 
-	if (setacl == true) {
+	if (setacl == 1) {
 	    if (verbose) {
 		printf("  Set acls for %s\n", file2);
 		fflush(stdout);
@@ -627,6 +615,11 @@ Copy(file1, file2, recursive, level)
 
 	    if (oldAcl) {
 		/* Get an old-style ACL and convert it */
+                if (verbose) {
+                    printf("  Getting old style acl\n");
+                    fflush(stdout);
+                }
+
 		for (i = 1; i < strlen(file1); i++)
 		    if (file1[i] == '/')
 			break;
@@ -642,7 +635,11 @@ Copy(file1, file2, recursive, level)
 		close(tfd);
 		if (code < 0) {
 		    if (errno == EINVAL) {
-			setacl = false;
+			setacl = 0;
+                        if (verbose) {
+                            printf("  _VICEIOCTL(4) returns EINVAL\n");
+                            fflush(stdout);
+                        }
 		    } else {
 			return 1;
 		    }
@@ -655,10 +652,19 @@ Copy(file1, file2, recursive, level)
 	    } /*Grab and convert old-style ACL */
 	    else {
 		/* Get a new-style ACL */
+                if (verbose) {
+                    printf("  Getting new style acl\n");
+                    fflush(stdout);
+                }
+
 		code = pioctl(file1, _VICEIOCTL(2), &blob, 1);
 		if (code < 0) {
 		    if (errno == EINVAL) {
-			setacl = false;
+			setacl = 0;
+                        if (verbose) {
+                            printf("  _VICEIOCTL(2) returns EINVAL\n");
+                            fflush(stdout);
+                        }
 		    } else {
 			perror("getacl ");
 			return 1;
@@ -669,7 +675,11 @@ Copy(file1, file2, recursive, level)
 	    /*
 	     * Now, set the new-style ACL.
 	     */
-	    if (setacl == true) {
+	    if (setacl == 1) {
+                if (verbose) {
+                    printf("  Setting new style acl\n");
+                    fflush(stdout);
+                }
 		blob.out = aclspace;
 		blob.in = aclspace;
 		blob.out_size = 0;
@@ -677,7 +687,11 @@ Copy(file1, file2, recursive, level)
 		code = pioctl(file2, _VICEIOCTL(1), &blob, 1);
 		if (code) {
 		    if (errno == EINVAL) {
-			setacl = false;
+			setacl = 0;
+                        if (verbose) {
+                            printf("  _VICEIOCTL(1) returns EINVAL\n");
+                            fflush(stdout);
+                        }
 		    } else {
 			fprintf(stderr, "Couldn't set acls for %s\n", file2);
 			return 1;
@@ -685,20 +699,27 @@ Copy(file1, file2, recursive, level)
 		}
 	    }
 
-	    if (setacl == false) {
+	    if (setacl == 0) {
 		printf("Not setting acls\n");
 	    }
 	}
+
+        /* preserve access and modification times: ("-x" disables) */
+        if (preserveDate) {
+            tv[0].tv_sec = s1.st_atime;
+            tv[0].tv_usec = 0;
+            tv[1].tv_sec = s1.st_mtime;
+            tv[1].tv_usec = 0;
+            utimes(file2, tv);
+        }
     }
 
     return rcode;
 }				/*Copy */
 
 
-int
-isMountPoint(name, blob)
-     char *name;
-     struct ViceIoctl *blob;
+static int
+isMountPoint(char *name, struct ViceIoctl *blob)
 {
     afs_int32 code;
     char true_name[1024];	/*dirname */
