@@ -17,8 +17,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/volser/voltrans.c,v 1.10.2.3 2007/10/30 15:24:12 shadow Exp $");
 
 #ifdef AFS_NT40_ENV
 #include <afs/afsutil.h>
@@ -75,20 +73,21 @@ struct volser_trans *
 NewTrans(afs_int32 avol, afs_int32 apart)
 {
     /* set volid, next, partition */
-    register struct volser_trans *tt;
+    struct volser_trans *tt, *newtt;
     struct timeval tp;
     struct timezone tzp;
 
+    newtt = (struct volser_trans *)malloc(sizeof(struct volser_trans));
     VTRANS_LOCK;
     /* don't allow the same volume to be attached twice */
     for (tt = allTrans; tt; tt = tt->next) {
 	if ((tt->volid == avol) && (tt->partition == apart)) {
 	    VTRANS_UNLOCK;
+	    free(newtt);
 	    return (struct volser_trans *)0;	/* volume busy */
 	}
     }
-    VTRANS_UNLOCK;
-    tt = (struct volser_trans *)malloc(sizeof(struct volser_trans));
+    tt = newtt;
     memset(tt, 0, sizeof(struct volser_trans));
     tt->volid = avol;
     tt->partition = apart;
@@ -98,9 +97,9 @@ NewTrans(afs_int32 avol, afs_int32 apart)
     gettimeofday(&tp, &tzp);
     tt->creationTime = tp.tv_sec;
     tt->time = FT_ApproxTime();
-    VTRANS_LOCK;
     tt->tid = transCounter++;
     tt->next = allTrans;
+    VTRANS_OBJ_LOCK_INIT(tt);
     allTrans = tt;
     VTRANS_UNLOCK;
     return tt;
@@ -150,6 +149,7 @@ DeleteTrans(register struct volser_trans *atrans, afs_int32 lock)
 	    if (tt->rxCallPtr)
 		rxi_CallError(tt->rxCallPtr, RX_CALL_DEAD);
 	    *lt = tt->next;
+	    VTRANS_OBJ_LOCK_DESTROY(tt);
 	    free(tt);
 	    if (lock) VTRANS_UNLOCK;
 	    return 0;
